# `model_selection_statsmodels`


![mkapi](skforecast.model_selection_statsmodels.backtesting_sarimax)
![mkapi](skforecast.model_selection_statsmodels.cv_sarimax)
![mkapi](skforecast.model_selection_statsmodels.grid_search_sarimax)

